# adarsh/portfolio.py
import textwrap

class Portfolio:
    def __init__(self):
        self.name = "Adarsh Kumar"
        self.contact = "+91 7004904210 | Vadodara, India"
        self.email = "a4adarshh@gmail.com"
        self.linkedin = "https://www.linkedin.com/in/adarsh-kumar"
        self.leetcode = "https://leetcode.com/adarsh_kumar"
        self.geeksforgeeks = "https://www.geeksforgeeks.org/adarsh_kumar"
        self.codechef = "https://www.codechef.com/users/adarsh_kumar"
        self.github = "https://github.com/adarsh-kumar"
        
        self.education = {
            "degree": "Bachelor of Technology in Computer Science and Engineering",
            "university": "Parul University, Vadodara",
            "years": "2023-2027",
            "cgpa": "8.50"
        }

        self.skills = {
            "Programming Languages": ["C/C++ (Proficient)", "Java and Python (Intermediate)", "JavaScript (Beginner)"],
            "Database and Tools": ["MySQL", "SQL (Intermediate)"],
            "Version Control and IDEs": ["Git", "GitHub", "Visual Studio Code", "IntelliJ IDEA"],
            "Coursework": [
                "Database and Management Systems", "Object-Oriented Programming", 
                "Software Development", "Computer Networks", "Operating Systems", 
                "Data Structures and Algorithms"
            ],
            "Soft Skills": [
                "Collaboration", "Communication", "Planning", "Teamwork", 
                "Time Management", "Leadership"
            ]
        }

        self.projects = [
            {
                "name": "Air Draw",
                "description": "Hand and finger-tip recognition, used for signature verification in the financial and online exam sectors.",
                "tech_stack": "Python",
                "github_link": "https://github.com/adarsh-kumar/air-draw"
            },
            {
                "name": "Hospital Management Program",
                "description": "Fully functional hospital management software with different access levels for admin, doctors, and patients.",
                "tech_stack": "Java, Java Swing",
                "github_link": "https://github.com/adarsh-kumar/hospital-management"
            }
        ]
        
        self.achievements = [
            "Won college-level coding challenges.",
            "Completed certification in Cyber Security by CISCO.",
            "Volunteered in college fests/events.",
            "Awarded leadership role in student organization."
        ]
    
    def show_all(self):
        # Print a separator for neatness
        self.print_separator()
        self.show_contact()
        self.print_separator()
        self.show_education()
        self.print_separator()
        self.show_skills()
        self.print_separator()
        self.show_projects()
        self.print_separator()
        self.show_achievements()
        self.print_separator()

    def print_separator(self):
        """Helper function to print a separator line for sections"""
        print("\n" + "-" * 80 + "\n")
    
    def center_text(self, text):
        """Center the text in the console"""
        width = 80  # Adjust this to change the width of the line
        wrapped_text = textwrap.fill(text, width)
        return "\n".join([line.center(width) for line in wrapped_text.split('\n')])
    
    def show_contact(self):
        contact_info = f"{self.name}\n{self.contact}\n{self.email}\n"
        contact_info += f"LinkedIn: {self.linkedin}\n"
        contact_info += f"Leetcode: {self.leetcode}\n"
        contact_info += f"GeeksforGeeks: {self.geeksforgeeks}\n"
        contact_info += f"CodeChef: {self.codechef}\n"
        contact_info += f"GitHub: {self.github}\n"
        print(self.center_text(contact_info))

    def show_education(self):
        education_info = f"Education:\n{self.education['degree']}, {self.education['university']} ({self.education['years']})\n"
        education_info += f"CGPA: {self.education['cgpa']}\n"
        print(self.center_text(education_info))

    def show_skills(self):
        skills_info = "Skills:\n"
        for category, skills in self.skills.items():
            skills_info += f"\n{category}:\n"
            for skill in skills:
                skills_info += f"  - {skill}\n"
        print(self.center_text(skills_info))

    def show_projects(self):
        projects_info = "Projects:\n"
        for project in self.projects:
            projects_info += f"Project Name: {project['name']}\n"
            projects_info += f"Description: {project['description']}\n"
            projects_info += f"Tech Stack: {project['tech_stack']}\n"
            projects_info += f"GitHub Link: {project['github_link']}\n\n"
        print(self.center_text(projects_info))

    def show_achievements(self):
        achievements_info = "Achievements & Extra-Curricular Activities:\n"
        for achievement in self.achievements:
            achievements_info += f"  - {achievement}\n"
        print(self.center_text(achievements_info))
